@@ -1,6 +1,5 @@
 require 'test_helper'
-# TODO: change back to "require 'backend/simple'" when dropping support to Ruby 1.8.7.
-require File.expand_path('../simple_test', __FILE__)
+require 'backend/simple_test'
 
 class I18nBackendMemoizeTest < I18nBackendSimpleTest
   module MemoizeSpy
